==> huaweicloudsdkbms-3.0.48-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/list_baremetal_flavor_detail_extends_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListBaremetalFlavorDetailExtendsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'flavors': 'list[FlavorsResp]'
    }

    attribute_map = {
        'flavors': 'flavors'
    }

    def __init__(self, flavors=None):
        """ListBaremetalFlavorDetailExtendsResponse - a model defined in huaweicloud sdk"""
        
        super(ListBaremetalFlavorDetailExtendsResponse, self).__init__()

        self._flavors = None
        self.discriminator = None

        if flavors is not None:
            self.flavors = flavors

    @property
    def flavors(self):
        """Gets the flavors of this ListBaremetalFlavorDetailExtendsResponse.

        裸金属服务器规格列表，详情请参见表2 flavors数据结构说明。

        :return: The flavors of this ListBaremetalFlavorDetailExtendsResponse.
        :rtype: list[FlavorsResp]
        """
        return self._flavors

    @flavors.setter
    def flavors(self, flavors):
        """Sets the flavors of this ListBaremetalFlavorDetailExtendsResponse.

        裸金属服务器规格列表，详情请参见表2 flavors数据结构说明。

        :param flavors: The flavors of this ListBaremetalFlavorDetailExtendsResponse.
        :type: list[FlavorsResp]
        """
        self._flavors = flavors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBaremetalFlavorDetailExtendsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbms-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/list_baremetal_flavor_detail_extends_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListBaremetalFlavorDetailExtendsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'flavors': 'list[FlavorsResp]'
    }

    attribute_map = {
        'flavors': 'flavors'
    }

    def __init__(self, flavors=None):
        """ListBaremetalFlavorDetailExtendsResponse - a model defined in huaweicloud sdk"""
        
        super(ListBaremetalFlavorDetailExtendsResponse, self).__init__()

        self._flavors = None
        self.discriminator = None

        if flavors is not None:
            self.flavors = flavors

    @property
    def flavors(self):
        """Gets the flavors of this ListBaremetalFlavorDetailExtendsResponse.

        裸金属服务器规格列表，详情请参见表2 flavors数据结构说明。

        :return: The flavors of this ListBaremetalFlavorDetailExtendsResponse.
        :rtype: list[FlavorsResp]
        """
        return self._flavors

    @flavors.setter
    def flavors(self, flavors):
        """Sets the flavors of this ListBaremetalFlavorDetailExtendsResponse.

        裸金属服务器规格列表，详情请参见表2 flavors数据结构说明。

        :param flavors: The flavors of this ListBaremetalFlavorDetailExtendsResponse.
        :type: list[FlavorsResp]
        """
        self._flavors = flavors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBaremetalFlavorDetailExtendsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
